@@ -19,7 +19,7 @@ from plotnine import *
 import matplotlib.pyplot as plt
 from scipy.stats import hypergeom
 from collections import defaultdict
-from PTE_config import db_config
+from .PTE_config import db_config
 
 # todo: conver all "concept" and "term" to "trait"
 # todo: Enricher initialize
@@ -361,10 +361,6 @@ class Gene_Ontology_enrichment:
         self.enrich_dataframe[ 'highest_neg_log_p_value_label' ] = highest_neg_log_p_value_label
 
 
-
-
-
-
     def save_result(self, enrich_result, save_path: str, prefix='EnrRiceTrait'):
 
         if not os.path.exists(save_path):
